@@ -1,5 +1,5 @@
 
-/*  $Header: /cvs/gnome/gcalctool/gcalctool/calctool.h,v 1.1.1.1 2002/06/05 16:59:19 richb Exp $
+/*  $Header: /cvs/gnome/gcalctool/gcalctool/calctool.h,v 1.5 2002/06/20 22:04:24 richb Exp $
  *
  *  Copyright (c) 1987-2002, Sun Microsystems, Inc.  All Rights Reserved.
  *  Sun considers its source code as an unpublished, proprietary
@@ -103,12 +103,8 @@ enum num_type { ENG, FIX, SCI };            /* Number display mode. */
 enum op_type { OP_SET, OP_CLEAR, OP_NOP };  /* Operation item settings. */
 
 /* Resources. */
-enum res_type { R_ACCURACY, R_BASE,     R_DISPLAY,  R_MODE,
-                R_REGS,     R_RHAND,    R_THREED,   R_TITLE,    R_TRIG,
-                R_DECDIG,   R_HEXDIG,   R_ARITHOP,  R_ADJUST,   R_PORTION,
-                R_FUNC,     R_MAINMODE, R_PLOGICAL, R_BLOGICAL, R_FIN,
-                R_TRIGMODE, R_TRIGCOL,  R_SCI,      R_BACK,     R_DISPCOL,
-                R_MEMORY,   R_TEXT,     R_BEEP
+enum res_type { R_ACCURACY, R_BASE,  R_DISPLAY, R_MODE, R_HELP,
+                R_REGS,     R_RHAND, R_TRIG,    R_BEEP
 };
 
 enum trig_type { DEG, GRAD, RAD };          /* Trigonometric types. */
@@ -252,8 +248,12 @@ enum trig_type { DEG, GRAD, RAD };          /* Trigonometric types. */
 
 #define NOBUTTONS      BROWS * BCOLS
 
+#ifndef CFNAME
+#define CFNAME         ".gcalctoolcf"
+#endif /*CFNAME*/
+
 #ifndef RCNAME
-#define RCNAME         ".calctoolrc"
+#define RCNAME         ".gcalctoolrc"
 #endif /*RCNAME*/
 
 #ifndef TRUE                    /* Boolean definitions. */
@@ -273,7 +273,6 @@ struct button {
     int value;               /* Unique button keyboard equivalent. */
     enum op_type opdisp;     /* Is button selected during operation? */
     enum menu_type mtype;    /* Type of popup menu (if any). */
-    char color;              /* Color of button portion. */
     void (*func)();          /* Function to obey on button press. */
 };
 
@@ -286,14 +285,14 @@ struct menu {
 
 struct calcVars {                      /* Calctool variables and options. */
     char *appname;                     /* Application name for resources. */
-    char *colstr[CALC_COLORSIZE];      /* X color resource strings. */
     char con_names[MAXREGS][MAXLINE];  /* Selectable constant names. */
     char cur_op;                       /* Current arithmetic operation. */
     char display[MAXLINE];             /* Current calculator display. */
     char *exp_posn;                    /* Position of the exponent sign. */
     char fnum[MAX_DIGITS+1];           /* Scratchpad for fixed numbers. */
-    char fun_names[MAXREGS][MAXLINE];  /* Function names from .calctoolrc. */
-    char fun_vals[MAXREGS][MAXLINE];   /* Function defs from .calctoolrc. */
+    char fun_names[MAXREGS][MAXLINE];  /* Function names from .gcalctoolcf. */
+    char fun_vals[MAXREGS][MAXLINE];   /* Function defs from .gcalctoolcf. */
+    char *home;                        /* Pathname for users home directory. */
     char *iconlabel;                   /* The calctool icon label. */
     char item_text[MAXITEMS][60];      /* Pseudo panel item text strings. */
     char old_cal_value;                /* Previous calculation operator. */
@@ -324,10 +323,6 @@ struct calcVars {                      /* Calctool variables and options. */
 
     struct button temp_buttons[BCOLS];   /* To setup "right-handed" version. */
 
-    int rcols[CALC_COLORSIZE];           /* Red colormap values. */
-    int gcols[CALC_COLORSIZE];           /* Green colormap values. */
-    int bcols[CALC_COLORSIZE];           /* Blue colormap values. */
-
     int accuracy;      /* Number of digits precision (Max 9). */
     int beep;          /* Indicates whether there is a beep sound on error. */
     int column;        /* Column number of current key/mouse press. */
@@ -343,9 +338,7 @@ struct calcVars {                      /* Calctool variables and options. */
     int iconic;        /* Set if window is currently iconic. */
     int iheight;       /* Initial height of the calctool window. */
     int inverse;       /* If set, trig and log functions will be inversed. */
-    int iscolor;       /* Set if this is a color screen. */
     int ismenu;        /* Set when do_pending called via a popup menu. */
-    int istitle;       /* Set if calctool frame has a title. */
     int iwidth;        /* Initial width of the calctool window. */
     int ix;            /* Initial X position of the icon. */
     int iy;            /* Initial Y position of the icon. */
@@ -365,6 +358,7 @@ struct calcVars {                      /* Calctool variables and options. */
     int righthand;     /* Set if this is a "right-handed" calculator. */
     int row;           /* Row number of current key/mouse press. */
     int rstate;        /* Indicates if memory register frame is displayed. */
+    int show_help;     /* Set if we wish to show tooltip help. */
     int show_paren;    /* Set if we wish to show DISPLAYITEM during parens. */
     int started;       /* Set just before window is displayed. */
     int toclear;       /* Indicates if display should be cleared. */
@@ -387,7 +381,6 @@ typedef struct calcVars *Vars;
 char *button_str(int);
 char *convert(char *);
 char *get_resource(enum res_type);
-char *help_button_str(int);
 char *make_number(int *);
 
 enum menu_type button_mtype(int);
@@ -402,7 +395,6 @@ int get_menu_entry(enum menu_type, int);
 int main(int, char **);
 
 void beep();
-void check_args();
 void clear_display();
 void display_prop_sheet();
 void do_ascii();
@@ -438,7 +430,6 @@ void init_frame_sizes();
 void init_vars();
 void init_Xvars(int *, char **);
 void key_init();
-void load_deskset_defs();
 void load_resources();
 void make_frames();
 void make_menus();
@@ -456,10 +447,10 @@ void put_resource(enum res_type, char *);
 void read_rcfiles();
 void read_resources();
 void read_str(char **, char *);
-void save_cmdline(int, char **);
 void save_pending_values(int);
 void save_resources();
 void set_button_state(enum fcp_type, int, int);
+void set_help_state(int);
 void set_ins_key();
 void set_item(enum item_type, char *);
 void set_label(enum item_type itemno, char *str);
@@ -467,13 +458,11 @@ void set_mode(enum mode_type);
 void set_title(enum fcp_type, char *);
 void show_ascii_frame();
 void show_display(int *);
-void show_help(char *);
 void srand48();
 void start_tool();
 void switch_hands(int);
 void usage(char *);
 void win_display(enum fcp_type, int);
-void write_cmdline();
 void write_rcfile(enum menu_type, int, int, char *, char *);
 void write_resources();
 
